@@ -3,7 +3,10 @@
 //pub mod captive;
 
 #[cfg(feature = "experimental")]
-pub mod nonblocking;
+pub mod asyncify;
+
+#[cfg(feature = "experimental")]
+pub mod asyncs;
 
 #[cfg(all(feature = "experimental", feature = "alloc", feature = "use_serde"))]
 pub mod ghota;
